pub struct AudioLoader;Expand description
Loads files as AudioSource Assets
This asset loader supports different audio formats based on the enable Bevy features.
The feature bevy/vorbis enables loading from .ogg files and is enabled by default.
Other file endings can be loaded from with additional features:
.mp3 with bevy/mp3
.flac with bevy/flac
.wav with bevy/wav