pub struct AudioPlugin {
pub global_volume: GlobalVolume,
pub default_spatial_scale: SpatialScale,
}Expand description
Adds support for audio playback to a Bevy Application
Insert an AudioPlayer onto your entities to play audio.
Fields
global_volume: GlobalVolumeThe global volume for all audio entities.
default_spatial_scale: SpatialScaleThe scale factor applied to the positions of audio sources and listeners for spatial audio.